package com.ynet.life.search;

import com.ynet.life.base.LifeDBAccess;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.loaf.jdbc.LoafQueryFactory;
import com.ynet.life.loaf.jdbc.LoafQueryInterface;
import com.ynet.life.search.core.IndexBuilderImpl;
import com.ynet.life.search.core.IndexSourceImpl;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.LinkedList;
import java.util.List;
import org.apache.lucene.document.Document;

/* loaded from: com_ynet_life_search.jar:com/ynet/life/search/AbstractDBIndexBuilder.class */
public abstract class AbstractDBIndexBuilder implements LifeIndexBuilder {
    private static final int BLOCK_SIZE = 1000;
    private String querySql;
    private String queryField;
    private String indexFolderFile;

    protected abstract Document getDocument(ResultSet resultSet) throws SQLException;

    public AbstractDBIndexBuilder(String indexFolderFile, String querySql, String queryField) {
        this.indexFolderFile = indexFolderFile;
        this.querySql = querySql;
        this.queryField = queryField;
    }

    @Override // com.ynet.life.search.LifeIndexBuilder
    public void buildIndex() throws TranFailException {
        Trace.logInfo("LifeSearch", "开始构建索引");
        IndexSourceImpl indexSourceImpl = new IndexSourceImpl(this.indexFolderFile, true);
        IndexBuilderImpl indexBuilderImpl = new IndexBuilderImpl(indexSourceImpl);
        int currentCount = 0;
        try {
            try {
                List input = new LinkedList();
                LoafQueryInterface query = LoafQueryFactory.getNewQuery(this.queryField, (String) null, this.querySql);
                Connection connection = LifeDBAccess.getConnection();
                int totalCount = query.getCount(connection, input);
                if (totalCount > 0) {
                    long sentinal = totalCount / BLOCK_SIZE;
                    int beginPos = 1;
                    for (int i = 0; i <= sentinal; i++) {
                        PreparedStatement ps = null;
                        ResultSet resultSet = null;
                        try {
                            try {
                                PreparedStatement queryByPageStatement = query.getQueryByPageStatement(connection, input, beginPos, BLOCK_SIZE);
                                ps = queryByPageStatement;
                                resultSet = queryByPageStatement.executeQuery();
                                while (resultSet.next()) {
                                    currentCount++;
                                    Document doc = getDocument(resultSet);
                                    indexBuilderImpl.addDocument(doc);
                                }
                                beginPos += BLOCK_SIZE;
                                LifeDBAccess.cleanResources(ps, resultSet);
                            } catch (Throwable th) {
                                LifeDBAccess.cleanResources(ps, resultSet);
                                throw th;
                            }
                        } catch (SQLException ex) {
                            throw new TranFailException("EBLN0000", ex);
                        }
                    }
                }
                Trace.logInfo("LifeSearch", "完成构建索引，需要构建数量：" + totalCount + "， 实际构建数量：" + currentCount);
                try {
                    LifeDBAccess.releaseConnection(connection);
                } catch (Exception unused) {
                }
                try {
                    indexBuilderImpl.close();
                    indexSourceImpl.close();
                } catch (Exception unused2) {
                }
            } catch (Exception e) {
                Trace.logError("LifeSearch", "构建索引失败", e);
                throw new TranFailException("构建索引失败", e);
            }
        } catch (Throwable th2) {
            try {
                LifeDBAccess.releaseConnection((Connection) null);
            } catch (Exception unused3) {
            }
            try {
                indexBuilderImpl.close();
                indexSourceImpl.close();
            } catch (Exception unused4) {
            }
            throw th2;
        }
    }
}
